aboutsummaryrefslogtreecommitdiff
path: root/lib/pop3.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/pop3.h')
-rw-r--r--lib/pop3.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/pop3.h b/lib/pop3.h
index 2d9610168..a8e697cde 100644
--- a/lib/pop3.h
+++ b/lib/pop3.h
@@ -45,9 +45,9 @@ typedef enum {
POP3_LAST /* never used */
} pop3state;
/* This POP3 struct is used in the SessionHandle. All POP3 data that is
connection-oriented must be in pop3_conn to properly deal with the fact that
- perhaps the SessionHandle is changed between the times the connection is
+ perhaps the Curl_easy is changed between the times the connection is
used. */
struct POP3 {
curl_pp_transfer transfer;
@@ -45,9 +45,9 @@ typedef enum {
POP3_LAST /* never used */
} pop3state;
-/* This POP3 struct is used in the SessionHandle. All POP3 data that is
+/* This POP3 struct is used in the Curl_easy. All POP3 data that is
connection-oriented must be in pop3_conn to properly deal with the fact that